package com.bpcl.lpg.core.credentials.dao.impl;

import com.bpcl.lpg.core.model.EasysecsModel;
import de.hybris.platform.servicelayer.search.SearchResult;
import java.util.Collection;
import org.apache.commons.collections4.CollectionUtils;
import java.util.Map;
import java.util.HashMap;
import com.bpcl.lpg.core.model.LPGNextApiCredsModel;
import de.hybris.platform.servicelayer.search.FlexibleSearchService;
import com.bpcl.lpg.core.credentials.dao.LPGCredentialsDao;

public class LPGCredentialsDaoImpl implements LPGCredentialsDao
{
    private FlexibleSearchService flexibleSearchService;
    
    public LPGNextApiCredsModel getCredsModelByApiName(final String apiName) {
        final String credentialsQuery = this.prepareCredentialsQuery();
        final Map<String, Object> credsParam = new HashMap<String, Object>();
        credsParam.put("apiName", apiName);
        final SearchResult<LPGNextApiCredsModel> result = (SearchResult<LPGNextApiCredsModel>)this.flexibleSearchService.search(credentialsQuery, (Map)credsParam);
        if (result != null && CollectionUtils.isNotEmpty((Collection)result.getResult())) {
            return result.getResult().get(0);
        }
        return new LPGNextApiCredsModel();
    }
    
    public EasysecsModel getSecretByKey(final String key) {
        final String query = "select {PK} from {Easysecs} where {key} = ?key";
        final Map<String, Object> queryParams = new HashMap<String, Object>();
        queryParams.put("key", key);
        final SearchResult<EasysecsModel> result = (SearchResult<EasysecsModel>)this.flexibleSearchService.search("select {PK} from {Easysecs} where {key} = ?key", (Map)queryParams);
        if (result != null && CollectionUtils.isNotEmpty((Collection)result.getResult())) {
            return result.getResult().get(0);
        }
        return new EasysecsModel();
    }
    
    private String prepareCredentialsQuery() {
        final StringBuilder query = new StringBuilder();
        query.append("SELECT {").append("pk").append("} FROM {").append("LPGNextApiCreds").append("} WHERE {");
        query.append("apiName").append("} = ?").append("apiName");
        return query.toString();
    }
    
    public void setFlexibleSearchService(final FlexibleSearchService flexibleSearchService) {
        this.flexibleSearchService = flexibleSearchService;
    }
}
